@@ -52,6 +52,8 @@ typedef struct
  * @FLATPAK_UPDATE_FLAGS_NONE: Fetch remote builds and install the latest one (default)
  * @FLATPAK_UPDATE_FLAGS_NO_DEPLOY: Don't install any new builds that might be fetched
  * @FLATPAK_UPDATE_FLAGS_NO_PULL: Don't try to fetch new builds from the remote repo
+ * @FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS: Don't use static deltas when pulling
+ * @FLATPAK_UPDATE_FLAGS_NO_PRUNE: Don't prune the local OSTree repository after updating (Since: 0.11.8)
  *
  * Flags to alter the behavior of flatpak_installation_update().
  */
@@ -60,11 +62,15 @@ typedef enum {
   FLATPAK_UPDATE_FLAGS_NO_DEPLOY        = (1 << 0),
   FLATPAK_UPDATE_FLAGS_NO_PULL          = (1 << 1),
   FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS = (1 << 2),
+  FLATPAK_UPDATE_FLAGS_NO_PRUNE         = (1 << 3),
 } FlatpakUpdateFlags;
 
 /**
  * FlatpakInstallFlags:
  * @FLATPAK_INSTALL_FLAGS_NONE: Default
+ * @FLATPAK_INSTALL_FLAGS_NO_STATIC_DELTAS: Don't use static deltas when pulling
+ * @FLATPAK_INSTALL_FLAGS_NO_DEPLOY: Don't install any new builds that might be fetched
+ * @FLATPAK_INSTALL_FLAGS_NO_PULL: Don't try to fetch new builds from the remote repo
  *
  * Flags to alter the behavior of flatpak_installation_install_full().
  */
@@ -75,12 +81,27 @@ typedef enum {
   FLATPAK_INSTALL_FLAGS_NO_PULL          = (1 << 3),
 } FlatpakInstallFlags;
 
+/**
+ * FlatpakUninstallFlags:
+ * @FLATPAK_UNINSTALL_FLAGS_NONE: Default
+ * @FLATPAK_UNINSTALL_FLAGS_NO_PRUNE: Don't prune the local OSTree repository after uninstalling
+ *
+ * Flags to alter the behavior of flatpak_installation_uninstall_full().
+ *
+ * Since: 0.11.8
+ */
+typedef enum {
+  FLATPAK_UNINSTALL_FLAGS_NONE     = 0,
+  FLATPAK_UNINSTALL_FLAGS_NO_PRUNE = (1 << 0),
+} FlatpakUninstallFlags;
+
 /**
  * FlatpakStorageType:
  * @FLATPAK_STORAGE_TYPE_DEFAULT: default
  * @FLATPAK_STORAGE_TYPE_HARD_DISK: installation is on a hard disk
  * @FLATPAK_STORAGE_TYPE_SDCARD: installation is on a SD card
  * @FLATPAK_STORAGE_TYPE_MMC: installation is on an MMC
+ * @FLATPAK_STORAGE_TYPE_NETWORK: installation is on the network
  *
  * Flags to alter the behavior of flatpak_installation_install_full().
  *
@@ -91,6 +112,7 @@ typedef enum {
   FLATPAK_STORAGE_TYPE_HARD_DISK,
   FLATPAK_STORAGE_TYPE_SDCARD,
   FLATPAK_STORAGE_TYPE_MMC,
+  FLATPAK_STORAGE_TYPE_NETWORK,
 } FlatpakStorageType;
 
 
@@ -174,9 +196,15 @@ FLATPAK_EXTERN FlatpakInstalledRef * flatpak_installation_get_current_installed_
                                                                                      const char          *name,
                                                                                      GCancellable        *cancellable,
                                                                                      GError             **error);
+
 FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes (FlatpakInstallation *self,
                                                                        GCancellable        *cancellable,
                                                                        GError             **error);
+FLATPAK_EXTERN GPtrArray           *flatpak_installation_list_remotes_by_type (FlatpakInstallation     *self,
+                                                                               const FlatpakRemoteType  types[],
+                                                                               gsize                    num_types,
+                                                                               GCancellable            *cancellable,
+                                                                               GError                 **error);
 FLATPAK_EXTERN FlatpakRemote        *flatpak_installation_get_remote_by_name (FlatpakInstallation *self,
                                                                               const gchar         *name,
                                                                               GCancellable        *cancellable,
@@ -269,6 +297,17 @@ FLATPAK_EXTERN gboolean             flatpak_installation_uninstall (FlatpakInsta
                                                                     GCancellable           *cancellable,
                                                                     GError                **error);
 
+FLATPAK_EXTERN gboolean             flatpak_installation_uninstall_full (FlatpakInstallation    *self,
+                                                                         FlatpakUninstallFlags   flags,
+                                                                         FlatpakRefKind          kind,
+                                                                         const char             *name,
+                                                                         const char             *arch,
+                                                                         const char             *branch,
+                                                                         FlatpakProgressCallback progress,
+                                                                         gpointer                progress_data,
+                                                                         GCancellable           *cancellable,
+                                                                         GError                **error);
+
 FLATPAK_EXTERN gboolean          flatpak_installation_fetch_remote_size_sync (FlatpakInstallation *self,
                                                                               const char          *remote_name,
                                                                               FlatpakRef          *ref,
@@ -282,7 +321,7 @@ FLATPAK_EXTERN GBytes        *   flatpak_installation_fetch_remote_metadata_sync
                                                                                   GCancellable        *cancellable,
                                                                                   GError             **error);
 FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_refs_sync (FlatpakInstallation *self,
-                                                                             const char          *remote_name,
+                                                                             const char          *remote_or_uri,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
 FLATPAK_EXTERN FlatpakRemoteRef  *flatpak_installation_fetch_remote_ref_sync (FlatpakInstallation *self,
